Class: NutanixVolumes::CommonV10ConfigEntityReference

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/nutanix_volumes/models/common_v10_config_entity_reference.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CommonV10ConfigEntityReference

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/nutanix_volumes/models/common_v10_config_entity_reference.rb', line 89

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVolumes::CommonV10ConfigEntityReference` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVolumes::CommonV10ConfigEntityReference`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ext_id')
    self.ext_id = attributes[:'ext_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'uris')
    if (value = attributes[:'uris']).is_a?(Array)
      self.uris = value
    end
  end

  if attributes.key?(:'entity_type')
    self.entity_type = attributes[:'entity_type']
  end
end

Instance Attribute Details

#entity_typeObject

Returns the value of attribute entity_type.



27
28
29
# File 'lib/nutanix_volumes/models/common_v10_config_entity_reference.rb', line 27

def entity_type
  @entity_type
end

#ext_idObject

A globally unique identifier of an instance that is suitable for external consumption.



19
20
21
# File 'lib/nutanix_volumes/models/common_v10_config_entity_reference.rb', line 19

def ext_id
  @ext_id
end

#nameObject

Name of entity that’s represented by this reference.



22
23
24
# File 'lib/nutanix_volumes/models/common_v10_config_entity_reference.rb', line 22

def name
  @name
end

#urisObject

URI of entities that’s represented by this reference.



25
26
27
# File 'lib/nutanix_volumes/models/common_v10_config_entity_reference.rb', line 25

def uris
  @uris
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



62
63
64
# File 'lib/nutanix_volumes/models/common_v10_config_entity_reference.rb', line 62

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



67
68
69
# File 'lib/nutanix_volumes/models/common_v10_config_entity_reference.rb', line 67

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
# File 'lib/nutanix_volumes/models/common_v10_config_entity_reference.rb', line 52

def self.attribute_map
  {
    :'ext_id' => :'extId',
    :'name' => :'name',
    :'uris' => :'uris',
    :'entity_type' => :'entityType'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/nutanix_volumes/models/common_v10_config_entity_reference.rb', line 231

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
# File 'lib/nutanix_volumes/models/common_v10_config_entity_reference.rb', line 82

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



72
73
74
75
76
77
78
79
# File 'lib/nutanix_volumes/models/common_v10_config_entity_reference.rb', line 72

def self.openapi_types
  {
    :'ext_id' => :'String',
    :'name' => :'String',
    :'uris' => :'Array<String>',
    :'entity_type' => :'CommonV10ConfigEntityType'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



207
208
209
210
211
212
213
214
# File 'lib/nutanix_volumes/models/common_v10_config_entity_reference.rb', line 207

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ext_id == o.ext_id &&
      name == o.name &&
      uris == o.uris &&
      entity_type == o.entity_type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


218
219
220
# File 'lib/nutanix_volumes/models/common_v10_config_entity_reference.rb', line 218

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



224
225
226
# File 'lib/nutanix_volumes/models/common_v10_config_entity_reference.rb', line 224

def hash
  [ext_id, name, uris, entity_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/nutanix_volumes/models/common_v10_config_entity_reference.rb', line 124

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  if !@ext_id.nil? && @ext_id !~ pattern
    invalid_properties.push("invalid value for \"ext_id\", must conform to the pattern #{pattern}.")
  end

  if !@name.nil? && @name.to_s.length > 256
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 256.')
  end

  if !@uris.nil? && @uris.length > 100
    invalid_properties.push('invalid value for "uris", number of items must be less than or equal to 100.')
  end

  if !@uris.nil? && @uris.length < 0
    invalid_properties.push('invalid value for "uris", number of items must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/nutanix_volumes/models/common_v10_config_entity_reference.rb', line 253

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



149
150
151
152
153
154
155
156
# File 'lib/nutanix_volumes/models/common_v10_config_entity_reference.rb', line 149

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@ext_id.nil? && @ext_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  return false if !@name.nil? && @name.to_s.length > 256
  return false if !@uris.nil? && @uris.length > 100
  return false if !@uris.nil? && @uris.length < 0
  true
end