Class: NutanixVolumes::CommonV10ConfigMetadata

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/nutanix_volumes/models/common_v10_config_metadata.rb

Overview

Metadata associated with this resource.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CommonV10ConfigMetadata

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/nutanix_volumes/models/common_v10_config_metadata.rb', line 74

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVolumes::CommonV10ConfigMetadata` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVolumes::CommonV10ConfigMetadata`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'owner_reference_id')
    self.owner_reference_id = attributes[:'owner_reference_id']
  end

  if attributes.key?(:'owner_user_name')
    self.owner_user_name = attributes[:'owner_user_name']
  end

  if attributes.key?(:'project_reference_id')
    self.project_reference_id = attributes[:'project_reference_id']
  end

  if attributes.key?(:'project_name')
    self.project_name = attributes[:'project_name']
  end

  if attributes.key?(:'category_ids')
    if (value = attributes[:'category_ids']).is_a?(Array)
      self.category_ids = value
    end
  end
end

Instance Attribute Details

#category_idsObject

A list of globally unique identifiers that represent all the categories the resource is associated with.



32
33
34
# File 'lib/nutanix_volumes/models/common_v10_config_metadata.rb', line 32

def category_ids
  @category_ids
end

#owner_reference_idObject

A globally unique identifier that represents the owner of this resource.



20
21
22
# File 'lib/nutanix_volumes/models/common_v10_config_metadata.rb', line 20

def owner_reference_id
  @owner_reference_id
end

#owner_user_nameObject

The userName of the owner of this resource.



23
24
25
# File 'lib/nutanix_volumes/models/common_v10_config_metadata.rb', line 23

def owner_user_name
  @owner_user_name
end

#project_nameObject

The name of the project this resource belongs to.



29
30
31
# File 'lib/nutanix_volumes/models/common_v10_config_metadata.rb', line 29

def project_name
  @project_name
end

#project_reference_idObject

A globally unique identifier that represents the project this resource belongs to.



26
27
28
# File 'lib/nutanix_volumes/models/common_v10_config_metadata.rb', line 26

def project_reference_id
  @project_reference_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



46
47
48
# File 'lib/nutanix_volumes/models/common_v10_config_metadata.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/nutanix_volumes/models/common_v10_config_metadata.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
# File 'lib/nutanix_volumes/models/common_v10_config_metadata.rb', line 35

def self.attribute_map
  {
    :'owner_reference_id' => :'ownerReferenceId',
    :'owner_user_name' => :'ownerUserName',
    :'project_reference_id' => :'projectReferenceId',
    :'project_name' => :'projectName',
    :'category_ids' => :'categoryIds'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/nutanix_volumes/models/common_v10_config_metadata.rb', line 261

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
# File 'lib/nutanix_volumes/models/common_v10_config_metadata.rb', line 67

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
# File 'lib/nutanix_volumes/models/common_v10_config_metadata.rb', line 56

def self.openapi_types
  {
    :'owner_reference_id' => :'String',
    :'owner_user_name' => :'String',
    :'project_reference_id' => :'String',
    :'project_name' => :'String',
    :'category_ids' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



236
237
238
239
240
241
242
243
244
# File 'lib/nutanix_volumes/models/common_v10_config_metadata.rb', line 236

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      owner_reference_id == o.owner_reference_id &&
      owner_user_name == o.owner_user_name &&
      project_reference_id == o.project_reference_id &&
      project_name == o.project_name &&
      category_ids == o.category_ids
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


248
249
250
# File 'lib/nutanix_volumes/models/common_v10_config_metadata.rb', line 248

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



254
255
256
# File 'lib/nutanix_volumes/models/common_v10_config_metadata.rb', line 254

def hash
  [owner_reference_id, owner_user_name, project_reference_id, project_name, category_ids].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/nutanix_volumes/models/common_v10_config_metadata.rb', line 113

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  if !@owner_reference_id.nil? && @owner_reference_id !~ pattern
    invalid_properties.push("invalid value for \"owner_reference_id\", must conform to the pattern #{pattern}.")
  end

  if !@owner_user_name.nil? && @owner_user_name.to_s.length > 128
    invalid_properties.push('invalid value for "owner_user_name", the character length must be smaller than or equal to 128.')
  end

  pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  if !@project_reference_id.nil? && @project_reference_id !~ pattern
    invalid_properties.push("invalid value for \"project_reference_id\", must conform to the pattern #{pattern}.")
  end

  if !@project_name.nil? && @project_name.to_s.length > 128
    invalid_properties.push('invalid value for "project_name", the character length must be smaller than or equal to 128.')
  end

  if !@category_ids.nil? && @category_ids.length > 256
    invalid_properties.push('invalid value for "category_ids", number of items must be less than or equal to 256.')
  end

  if !@category_ids.nil? && @category_ids.length < 1
    invalid_properties.push('invalid value for "category_ids", number of items must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/nutanix_volumes/models/common_v10_config_metadata.rb', line 283

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



147
148
149
150
151
152
153
154
155
156
# File 'lib/nutanix_volumes/models/common_v10_config_metadata.rb', line 147

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@owner_reference_id.nil? && @owner_reference_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  return false if !@owner_user_name.nil? && @owner_user_name.to_s.length > 128
  return false if !@project_reference_id.nil? && @project_reference_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  return false if !@project_name.nil? && @project_name.to_s.length > 128
  return false if !@category_ids.nil? && @category_ids.length > 256
  return false if !@category_ids.nil? && @category_ids.length < 1
  true
end