Class: NutanixVolumes::VolumesV40ConfigCategoryDetails
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixVolumes::VolumesV40ConfigCategoryDetails
- Defined in:
- lib/nutanix_volumes/models/volumes_v40_config_category_details.rb
Overview
An existing category detail associated with the Volume Group.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#entity_type ⇒ Object
Returns the value of attribute entity_type.
-
#ext_id ⇒ Object
A globally unique identifier of an instance that is suitable for external consumption.
-
#name ⇒ Object
Name of entity that’s represented by this reference.
-
#uris ⇒ Object
URI of entities that’s represented by this reference.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VolumesV40ConfigCategoryDetails
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VolumesV40ConfigCategoryDetails
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_category_details.rb', line 97 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVolumes::VolumesV40ConfigCategoryDetails` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVolumes::VolumesV40ConfigCategoryDetails`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'ext_id') self.ext_id = attributes[:'ext_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'uris') if (value = attributes[:'uris']).is_a?(Array) self.uris = value end end if attributes.key?(:'entity_type') self.entity_type = attributes[:'entity_type'] end end |
Instance Attribute Details
#entity_type ⇒ Object
Returns the value of attribute entity_type.
28 29 30 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_category_details.rb', line 28 def entity_type @entity_type end |
#ext_id ⇒ Object
A globally unique identifier of an instance that is suitable for external consumption.
20 21 22 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_category_details.rb', line 20 def ext_id @ext_id end |
#name ⇒ Object
Name of entity that’s represented by this reference.
23 24 25 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_category_details.rb', line 23 def name @name end |
#uris ⇒ Object
URI of entities that’s represented by this reference.
26 27 28 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_category_details.rb', line 26 def uris @uris end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
63 64 65 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_category_details.rb', line 63 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
68 69 70 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_category_details.rb', line 68 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_category_details.rb', line 53 def self.attribute_map { :'ext_id' => :'extId', :'name' => :'name', :'uris' => :'uris', :'entity_type' => :'entityType' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_category_details.rb', line 239 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
89 90 91 92 93 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_category_details.rb', line 89 def self.openapi_all_of [ :'CommonV10ConfigEntityReference' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
83 84 85 86 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_category_details.rb', line 83 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_category_details.rb', line 73 def self.openapi_types { :'ext_id' => :'String', :'name' => :'String', :'uris' => :'Array<String>', :'entity_type' => :'CommonV10ConfigEntityType' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
215 216 217 218 219 220 221 222 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_category_details.rb', line 215 def ==(o) return true if self.equal?(o) self.class == o.class && ext_id == o.ext_id && name == o.name && uris == o.uris && entity_type == o.entity_type end |
#eql?(o) ⇒ Boolean
226 227 228 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_category_details.rb', line 226 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
232 233 234 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_category_details.rb', line 232 def hash [ext_id, name, uris, entity_type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_category_details.rb', line 132 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@ext_id.nil? && @ext_id !~ pattern invalid_properties.push("invalid value for \"ext_id\", must conform to the pattern #{pattern}.") end if !@name.nil? && @name.to_s.length > 256 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 256.') end if !@uris.nil? && @uris.length > 100 invalid_properties.push('invalid value for "uris", number of items must be less than or equal to 100.') end if !@uris.nil? && @uris.length < 0 invalid_properties.push('invalid value for "uris", number of items must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_category_details.rb', line 261 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
157 158 159 160 161 162 163 164 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_category_details.rb', line 157 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@ext_id.nil? && @ext_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) return false if !@name.nil? && @name.to_s.length > 256 return false if !@uris.nil? && @uris.length > 100 return false if !@uris.nil? && @uris.length < 0 true end |