Class: NutanixVolumes::VolumesV40ConfigIscsiFeatures
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixVolumes::VolumesV40ConfigIscsiFeatures
- Defined in:
- lib/nutanix_volumes/models/volumes_v40_config_iscsi_features.rb
Overview
iSCSI specific settings for the Volume Group. This is an optional field.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#enabled_authentications ⇒ Object
Returns the value of attribute enabled_authentications.
-
#target_secret ⇒ Object
Target secret in case of a CHAP authentication.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VolumesV40ConfigIscsiFeatures
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VolumesV40ConfigIscsiFeatures
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_features.rb', line 80 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVolumes::VolumesV40ConfigIscsiFeatures` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVolumes::VolumesV40ConfigIscsiFeatures`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'target_secret') self.target_secret = attributes[:'target_secret'] end if attributes.key?(:'enabled_authentications') self.enabled_authentications = attributes[:'enabled_authentications'] end end |
Instance Attribute Details
#enabled_authentications ⇒ Object
Returns the value of attribute enabled_authentications.
22 23 24 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_features.rb', line 22 def enabled_authentications @enabled_authentications end |
#target_secret ⇒ Object
Target secret in case of a CHAP authentication. This field must only be provided in case the authentication type is not set to CHAP. This is an optional field and it cannot be retrieved once configured.
20 21 22 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_features.rb', line 20 def target_secret @target_secret end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
55 56 57 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_features.rb', line 55 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
60 61 62 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_features.rb', line 60 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_features.rb', line 47 def self.attribute_map { :'target_secret' => :'targetSecret', :'enabled_authentications' => :'enabledAuthentications' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_features.rb', line 170 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
73 74 75 76 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_features.rb', line 73 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_features.rb', line 65 def self.openapi_types { :'target_secret' => :'String', :'enabled_authentications' => :'VolumesV40ConfigAuthenticationType' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
148 149 150 151 152 153 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_features.rb', line 148 def ==(o) return true if self.equal?(o) self.class == o.class && target_secret == o.target_secret && enabled_authentications == o.enabled_authentications end |
#eql?(o) ⇒ Boolean
157 158 159 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_features.rb', line 157 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
163 164 165 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_features.rb', line 163 def hash [target_secret, enabled_authentications].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_features.rb', line 105 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@target_secret.nil? && @target_secret.to_s.length > 16 invalid_properties.push('invalid value for "target_secret", the character length must be smaller than or equal to 16.') end if !@target_secret.nil? && @target_secret.to_s.length < 12 invalid_properties.push('invalid value for "target_secret", the character length must be greater than or equal to 12.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_features.rb', line 192 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
121 122 123 124 125 126 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_features.rb', line 121 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@target_secret.nil? && @target_secret.to_s.length > 16 return false if !@target_secret.nil? && @target_secret.to_s.length < 12 true end |