Class: NutanixVolumes::VolumesV40ConfigNvmfClient
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixVolumes::VolumesV40ConfigNvmfClient
- Defined in:
- lib/nutanix_volumes/models/volumes_v40_config_nvmf_client.rb
Overview
A model that represents a NVMf client that can be associated with a Volume Group as an external attachment.
Instance Attribute Summary collapse
-
#attached_targets ⇒ Object
List of all subsystems connected to a NVMf client.
-
#cluster_reference ⇒ Object
The UUID of the cluster that will host the NVMf client.
-
#ext_id ⇒ Object
A globally unique identifier of an instance that is suitable for external consumption.
-
#links ⇒ Object
A HATEOAS style link for the response.
-
#nvmf_initiator_name ⇒ Object
NVMf client qualified name.
-
#tenant_id ⇒ Object
A globally unique identifier that represents the tenant that owns this entity.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VolumesV40ConfigNvmfClient
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VolumesV40ConfigNvmfClient
Initializes the object
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_nvmf_client.rb', line 87 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVolumes::VolumesV40ConfigNvmfClient` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVolumes::VolumesV40ConfigNvmfClient`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'tenant_id') self.tenant_id = attributes[:'tenant_id'] end if attributes.key?(:'ext_id') self.ext_id = attributes[:'ext_id'] end if attributes.key?(:'links') if (value = attributes[:'links']).is_a?(Array) self.links = value end end if attributes.key?(:'nvmf_initiator_name') self.nvmf_initiator_name = attributes[:'nvmf_initiator_name'] end if attributes.key?(:'attached_targets') if (value = attributes[:'attached_targets']).is_a?(Array) self.attached_targets = value end end if attributes.key?(:'cluster_reference') self.cluster_reference = attributes[:'cluster_reference'] end end |
Instance Attribute Details
#attached_targets ⇒ Object
List of all subsystems connected to a NVMf client.
32 33 34 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_nvmf_client.rb', line 32 def attached_targets @attached_targets end |
#cluster_reference ⇒ Object
The UUID of the cluster that will host the NVMf client.
35 36 37 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_nvmf_client.rb', line 35 def cluster_reference @cluster_reference end |
#ext_id ⇒ Object
A globally unique identifier of an instance that is suitable for external consumption.
23 24 25 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_nvmf_client.rb', line 23 def ext_id @ext_id end |
#links ⇒ Object
A HATEOAS style link for the response. Each link contains a user-friendly name identifying the link and an address for retrieving the particular resource.
26 27 28 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_nvmf_client.rb', line 26 def links @links end |
#nvmf_initiator_name ⇒ Object
NVMf client qualified name.
29 30 31 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_nvmf_client.rb', line 29 def nvmf_initiator_name @nvmf_initiator_name end |
#tenant_id ⇒ Object
A globally unique identifier that represents the tenant that owns this entity. The system automatically assigns it, and it and is immutable from an API consumer perspective (some use cases may cause this Id to change - For instance, a use case may require the transfer of ownership of the entity, but these cases are handled automatically on the server).
20 21 22 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_nvmf_client.rb', line 20 def tenant_id @tenant_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
50 51 52 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_nvmf_client.rb', line 50 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_nvmf_client.rb', line 55 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_nvmf_client.rb', line 38 def self.attribute_map { :'tenant_id' => :'tenantId', :'ext_id' => :'extId', :'links' => :'links', :'nvmf_initiator_name' => :'nvmfInitiatorName', :'attached_targets' => :'attachedTargets', :'cluster_reference' => :'clusterReference' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_nvmf_client.rb', line 307 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
79 80 81 82 83 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_nvmf_client.rb', line 79 def self.openapi_all_of [ :'CommonV10ResponseExternalizableAbstractModel' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 76 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_nvmf_client.rb', line 72 def self.openapi_nullable Set.new([ :'ext_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_nvmf_client.rb', line 60 def self.openapi_types { :'tenant_id' => :'String', :'ext_id' => :'String', :'links' => :'Array<CommonV10ResponseApiLink>', :'nvmf_initiator_name' => :'String', :'attached_targets' => :'Array<String>', :'cluster_reference' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
281 282 283 284 285 286 287 288 289 290 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_nvmf_client.rb', line 281 def ==(o) return true if self.equal?(o) self.class == o.class && tenant_id == o.tenant_id && ext_id == o.ext_id && links == o.links && nvmf_initiator_name == o.nvmf_initiator_name && attached_targets == o.attached_targets && cluster_reference == o.cluster_reference end |
#eql?(o) ⇒ Boolean
294 295 296 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_nvmf_client.rb', line 294 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
300 301 302 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_nvmf_client.rb', line 300 def hash [tenant_id, ext_id, links, nvmf_initiator_name, attached_targets, cluster_reference].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_nvmf_client.rb', line 132 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@tenant_id.nil? && @tenant_id !~ pattern invalid_properties.push("invalid value for \"tenant_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@ext_id.nil? && @ext_id !~ pattern invalid_properties.push("invalid value for \"ext_id\", must conform to the pattern #{pattern}.") end if !@links.nil? && @links.length > 20 invalid_properties.push('invalid value for "links", number of items must be less than or equal to 20.') end if !@links.nil? && @links.length < 0 invalid_properties.push('invalid value for "links", number of items must be greater than or equal to 0.') end if !@nvmf_initiator_name.nil? && @nvmf_initiator_name.to_s.length > 68 invalid_properties.push('invalid value for "nvmf_initiator_name", the character length must be smaller than or equal to 68.') end if !@attached_targets.nil? && @attached_targets.length > 20 invalid_properties.push('invalid value for "attached_targets", number of items must be less than or equal to 20.') end if !@attached_targets.nil? && @attached_targets.length < 0 invalid_properties.push('invalid value for "attached_targets", number of items must be greater than or equal to 0.') end pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@cluster_reference.nil? && @cluster_reference !~ pattern invalid_properties.push("invalid value for \"cluster_reference\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_nvmf_client.rb', line 329 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_nvmf_client.rb', line 175 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@tenant_id.nil? && @tenant_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) return false if !@ext_id.nil? && @ext_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) return false if !@links.nil? && @links.length > 20 return false if !@links.nil? && @links.length < 0 return false if !@nvmf_initiator_name.nil? && @nvmf_initiator_name.to_s.length > 68 return false if !@attached_targets.nil? && @attached_targets.length > 20 return false if !@attached_targets.nil? && @attached_targets.length < 0 return false if !@cluster_reference.nil? && @cluster_reference !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) true end |