Class: NutanixVolumes::VolumesV40ConfigVmAttachment

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/nutanix_volumes/models/volumes_v40_config_vm_attachment.rb

Overview

A model that represents a VM reference that can be associated with a Volume Group as an AHV hypervisor attachment.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ VolumesV40ConfigVmAttachment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/nutanix_volumes/models/volumes_v40_config_vm_attachment.rb', line 59

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVolumes::VolumesV40ConfigVmAttachment` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVolumes::VolumesV40ConfigVmAttachment`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ext_id')
    self.ext_id = attributes[:'ext_id']
  else
    self.ext_id = nil
  end

  if attributes.key?(:'index')
    self.index = attributes[:'index']
  end
end

Instance Attribute Details

#ext_idObject

The external identifier of the VM.



20
21
22
# File 'lib/nutanix_volumes/models/volumes_v40_config_vm_attachment.rb', line 20

def ext_id
  @ext_id
end

#indexObject

The index on the SCSI bus to attach the VM to the Volume Group. This is an optional field.



23
24
25
# File 'lib/nutanix_volumes/models/volumes_v40_config_vm_attachment.rb', line 23

def index
  @index
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



34
35
36
# File 'lib/nutanix_volumes/models/volumes_v40_config_vm_attachment.rb', line 34

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



39
40
41
# File 'lib/nutanix_volumes/models/volumes_v40_config_vm_attachment.rb', line 39

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



26
27
28
29
30
31
# File 'lib/nutanix_volumes/models/volumes_v40_config_vm_attachment.rb', line 26

def self.attribute_map
  {
    :'ext_id' => :'extId',
    :'index' => :'index'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/nutanix_volumes/models/volumes_v40_config_vm_attachment.rb', line 149

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



52
53
54
55
# File 'lib/nutanix_volumes/models/volumes_v40_config_vm_attachment.rb', line 52

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



44
45
46
47
48
49
# File 'lib/nutanix_volumes/models/volumes_v40_config_vm_attachment.rb', line 44

def self.openapi_types
  {
    :'ext_id' => :'String',
    :'index' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



127
128
129
130
131
132
# File 'lib/nutanix_volumes/models/volumes_v40_config_vm_attachment.rb', line 127

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ext_id == o.ext_id &&
      index == o.index
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


136
137
138
# File 'lib/nutanix_volumes/models/volumes_v40_config_vm_attachment.rb', line 136

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



142
143
144
# File 'lib/nutanix_volumes/models/volumes_v40_config_vm_attachment.rb', line 142

def hash
  [ext_id, index].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/nutanix_volumes/models/volumes_v40_config_vm_attachment.rb', line 86

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @ext_id.nil?
    invalid_properties.push('invalid value for "ext_id", ext_id cannot be nil.')
  end

  pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  if @ext_id !~ pattern
    invalid_properties.push("invalid value for \"ext_id\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/nutanix_volumes/models/volumes_v40_config_vm_attachment.rb', line 171

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



103
104
105
106
107
108
# File 'lib/nutanix_volumes/models/volumes_v40_config_vm_attachment.rb', line 103

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @ext_id.nil?
  return false if @ext_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  true
end