Class: NutanixVolumes::VolumesV40StatsVolumeDiskStats

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/nutanix_volumes/models/volumes_v40_stats_volume_disk_stats.rb

Overview

A model that stores the Volume disk stats.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ VolumesV40StatsVolumeDiskStats

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/nutanix_volumes/models/volumes_v40_stats_volume_disk_stats.rb', line 127

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVolumes::VolumesV40StatsVolumeDiskStats` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVolumes::VolumesV40StatsVolumeDiskStats`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'tenant_id')
    self.tenant_id = attributes[:'tenant_id']
  end

  if attributes.key?(:'ext_id')
    self.ext_id = attributes[:'ext_id']
  end

  if attributes.key?(:'links')
    if (value = attributes[:'links']).is_a?(Array)
      self.links = value
    end
  end

  if attributes.key?(:'volume_disk_ext_id')
    self.volume_disk_ext_id = attributes[:'volume_disk_ext_id']
  end

  if attributes.key?(:'controller_user_bytes')
    if (value = attributes[:'controller_user_bytes']).is_a?(Array)
      self.controller_user_bytes = value
    end
  end

  if attributes.key?(:'controller_num_iops')
    if (value = attributes[:'controller_num_iops']).is_a?(Array)
      self.controller_num_iops = value
    end
  end

  if attributes.key?(:'controller_num_read_iops')
    if (value = attributes[:'controller_num_read_iops']).is_a?(Array)
      self.controller_num_read_iops = value
    end
  end

  if attributes.key?(:'controller_num_write_iops')
    if (value = attributes[:'controller_num_write_iops']).is_a?(Array)
      self.controller_num_write_iops = value
    end
  end

  if attributes.key?(:'controller_io_bandwidth_k_bps')
    if (value = attributes[:'controller_io_bandwidth_k_bps']).is_a?(Array)
      self.controller_io_bandwidth_k_bps = value
    end
  end

  if attributes.key?(:'controller_read_io_bandwidth_k_bps')
    if (value = attributes[:'controller_read_io_bandwidth_k_bps']).is_a?(Array)
      self.controller_read_io_bandwidth_k_bps = value
    end
  end

  if attributes.key?(:'controller_write_io_bandwidth_k_bps')
    if (value = attributes[:'controller_write_io_bandwidth_k_bps']).is_a?(Array)
      self.controller_write_io_bandwidth_k_bps = value
    end
  end

  if attributes.key?(:'controller_avg_io_latency_usecs')
    if (value = attributes[:'controller_avg_io_latency_usecs']).is_a?(Array)
      self.controller_avg_io_latency_usecs = value
    end
  end

  if attributes.key?(:'controller_avg_read_io_latency_usecs')
    if (value = attributes[:'controller_avg_read_io_latency_usecs']).is_a?(Array)
      self.controller_avg_read_io_latency_usecs = value
    end
  end

  if attributes.key?(:'controller_avg_write_io_latency_usecs')
    if (value = attributes[:'controller_avg_write_io_latency_usecs']).is_a?(Array)
      self.controller_avg_write_io_latency_usecs = value
    end
  end
end

Instance Attribute Details

#controller_avg_io_latency_usecsObject

Controller average I/O latency measured in microseconds.



53
54
55
# File 'lib/nutanix_volumes/models/volumes_v40_stats_volume_disk_stats.rb', line 53

def controller_avg_io_latency_usecs
  @controller_avg_io_latency_usecs
end

#controller_avg_read_io_latency_usecsObject

Controller average read I/O latency measured in microseconds.



56
57
58
# File 'lib/nutanix_volumes/models/volumes_v40_stats_volume_disk_stats.rb', line 56

def controller_avg_read_io_latency_usecs
  @controller_avg_read_io_latency_usecs
end

#controller_avg_write_io_latency_usecsObject

Controller average write I/O latency measured in microseconds.



59
60
61
# File 'lib/nutanix_volumes/models/volumes_v40_stats_volume_disk_stats.rb', line 59

def controller_avg_write_io_latency_usecs
  @controller_avg_write_io_latency_usecs
end

#controller_io_bandwidth_k_bpsObject

Controller I/O bandwidth measured in Kbps.



44
45
46
# File 'lib/nutanix_volumes/models/volumes_v40_stats_volume_disk_stats.rb', line 44

def controller_io_bandwidth_k_bps
  @controller_io_bandwidth_k_bps
end

#controller_num_iopsObject

Controller I/O rate measured in iops.



35
36
37
# File 'lib/nutanix_volumes/models/volumes_v40_stats_volume_disk_stats.rb', line 35

def controller_num_iops
  @controller_num_iops
end

#controller_num_read_iopsObject

Controller read I/O measured in iops.



38
39
40
# File 'lib/nutanix_volumes/models/volumes_v40_stats_volume_disk_stats.rb', line 38

def controller_num_read_iops
  @controller_num_read_iops
end

#controller_num_write_iopsObject

Controller write I/O measured in iops.



41
42
43
# File 'lib/nutanix_volumes/models/volumes_v40_stats_volume_disk_stats.rb', line 41

def controller_num_write_iops
  @controller_num_write_iops
end

#controller_read_io_bandwidth_k_bpsObject

Controller read I/O bandwidth measured in Kbps.



47
48
49
# File 'lib/nutanix_volumes/models/volumes_v40_stats_volume_disk_stats.rb', line 47

def controller_read_io_bandwidth_k_bps
  @controller_read_io_bandwidth_k_bps
end

#controller_user_bytesObject

Controller user bytes.



32
33
34
# File 'lib/nutanix_volumes/models/volumes_v40_stats_volume_disk_stats.rb', line 32

def controller_user_bytes
  @controller_user_bytes
end

#controller_write_io_bandwidth_k_bpsObject

Controller write I/O bandwidth measured in Kbps.



50
51
52
# File 'lib/nutanix_volumes/models/volumes_v40_stats_volume_disk_stats.rb', line 50

def controller_write_io_bandwidth_k_bps
  @controller_write_io_bandwidth_k_bps
end

#ext_idObject

A globally unique identifier of an instance that is suitable for external consumption.



23
24
25
# File 'lib/nutanix_volumes/models/volumes_v40_stats_volume_disk_stats.rb', line 23

def ext_id
  @ext_id
end

A HATEOAS style link for the response. Each link contains a user-friendly name identifying the link and an address for retrieving the particular resource.



26
27
28
# File 'lib/nutanix_volumes/models/volumes_v40_stats_volume_disk_stats.rb', line 26

def links
  @links
end

#tenant_idObject

A globally unique identifier that represents the tenant that owns this entity. The system automatically assigns it, and it and is immutable from an API consumer perspective (some use cases may cause this Id to change - For instance, a use case may require the transfer of ownership of the entity, but these cases are handled automatically on the server).



20
21
22
# File 'lib/nutanix_volumes/models/volumes_v40_stats_volume_disk_stats.rb', line 20

def tenant_id
  @tenant_id
end

#volume_disk_ext_idObject

Uuid of the Volume Disk.



29
30
31
# File 'lib/nutanix_volumes/models/volumes_v40_stats_volume_disk_stats.rb', line 29

def volume_disk_ext_id
  @volume_disk_ext_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



82
83
84
# File 'lib/nutanix_volumes/models/volumes_v40_stats_volume_disk_stats.rb', line 82

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



87
88
89
# File 'lib/nutanix_volumes/models/volumes_v40_stats_volume_disk_stats.rb', line 87

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/nutanix_volumes/models/volumes_v40_stats_volume_disk_stats.rb', line 62

def self.attribute_map
  {
    :'tenant_id' => :'tenantId',
    :'ext_id' => :'extId',
    :'links' => :'links',
    :'volume_disk_ext_id' => :'volumeDiskExtId',
    :'controller_user_bytes' => :'controllerUserBytes',
    :'controller_num_iops' => :'controllerNumIOPS',
    :'controller_num_read_iops' => :'controllerNumReadIOPS',
    :'controller_num_write_iops' => :'controllerNumWriteIOPS',
    :'controller_io_bandwidth_k_bps' => :'controllerIOBandwidthKBps',
    :'controller_read_io_bandwidth_k_bps' => :'controllerReadIOBandwidthKBps',
    :'controller_write_io_bandwidth_k_bps' => :'controllerWriteIOBandwidthKBps',
    :'controller_avg_io_latency_usecs' => :'controllerAvgIOLatencyUsecs',
    :'controller_avg_read_io_latency_usecs' => :'controllerAvgReadIOLatencyUsecs',
    :'controller_avg_write_io_latency_usecs' => :'controllerAvgWriteIOLatencyUsecs'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
# File 'lib/nutanix_volumes/models/volumes_v40_stats_volume_disk_stats.rb', line 638

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



119
120
121
122
123
# File 'lib/nutanix_volumes/models/volumes_v40_stats_volume_disk_stats.rb', line 119

def self.openapi_all_of
  [
  :'CommonV10ResponseExternalizableAbstractModel'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



112
113
114
115
116
# File 'lib/nutanix_volumes/models/volumes_v40_stats_volume_disk_stats.rb', line 112

def self.openapi_nullable
  Set.new([
    :'ext_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/nutanix_volumes/models/volumes_v40_stats_volume_disk_stats.rb', line 92

def self.openapi_types
  {
    :'tenant_id' => :'String',
    :'ext_id' => :'String',
    :'links' => :'Array<CommonV10ResponseApiLink>',
    :'volume_disk_ext_id' => :'String',
    :'controller_user_bytes' => :'Array<VolumesV40StatsTimeValuePair>',
    :'controller_num_iops' => :'Array<VolumesV40StatsTimeValuePair>',
    :'controller_num_read_iops' => :'Array<VolumesV40StatsTimeValuePair>',
    :'controller_num_write_iops' => :'Array<VolumesV40StatsTimeValuePair>',
    :'controller_io_bandwidth_k_bps' => :'Array<VolumesV40StatsTimeValuePair>',
    :'controller_read_io_bandwidth_k_bps' => :'Array<VolumesV40StatsTimeValuePair>',
    :'controller_write_io_bandwidth_k_bps' => :'Array<VolumesV40StatsTimeValuePair>',
    :'controller_avg_io_latency_usecs' => :'Array<VolumesV40StatsTimeValuePair>',
    :'controller_avg_read_io_latency_usecs' => :'Array<VolumesV40StatsTimeValuePair>',
    :'controller_avg_write_io_latency_usecs' => :'Array<VolumesV40StatsTimeValuePair>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
# File 'lib/nutanix_volumes/models/volumes_v40_stats_volume_disk_stats.rb', line 604

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      tenant_id == o.tenant_id &&
      ext_id == o.ext_id &&
      links == o.links &&
      volume_disk_ext_id == o.volume_disk_ext_id &&
      controller_user_bytes == o.controller_user_bytes &&
      controller_num_iops == o.controller_num_iops &&
      controller_num_read_iops == o.controller_num_read_iops &&
      controller_num_write_iops == o.controller_num_write_iops &&
      controller_io_bandwidth_k_bps == o.controller_io_bandwidth_k_bps &&
      controller_read_io_bandwidth_k_bps == o.controller_read_io_bandwidth_k_bps &&
      controller_write_io_bandwidth_k_bps == o.controller_write_io_bandwidth_k_bps &&
      controller_avg_io_latency_usecs == o.controller_avg_io_latency_usecs &&
      controller_avg_read_io_latency_usecs == o.controller_avg_read_io_latency_usecs &&
      controller_avg_write_io_latency_usecs == o.controller_avg_write_io_latency_usecs
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


625
626
627
# File 'lib/nutanix_volumes/models/volumes_v40_stats_volume_disk_stats.rb', line 625

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



631
632
633
# File 'lib/nutanix_volumes/models/volumes_v40_stats_volume_disk_stats.rb', line 631

def hash
  [tenant_id, ext_id, links, volume_disk_ext_id, controller_user_bytes, controller_num_iops, controller_num_read_iops, controller_num_write_iops, controller_io_bandwidth_k_bps, controller_read_io_bandwidth_k_bps, controller_write_io_bandwidth_k_bps, controller_avg_io_latency_usecs, controller_avg_read_io_latency_usecs, controller_avg_write_io_latency_usecs].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/nutanix_volumes/models/volumes_v40_stats_volume_disk_stats.rb', line 222

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  if !@tenant_id.nil? && @tenant_id !~ pattern
    invalid_properties.push("invalid value for \"tenant_id\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  if !@ext_id.nil? && @ext_id !~ pattern
    invalid_properties.push("invalid value for \"ext_id\", must conform to the pattern #{pattern}.")
  end

  if !@links.nil? && @links.length > 20
    invalid_properties.push('invalid value for "links", number of items must be less than or equal to 20.')
  end

  if !@links.nil? && @links.length < 0
    invalid_properties.push('invalid value for "links", number of items must be greater than or equal to 0.')
  end

  pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  if !@volume_disk_ext_id.nil? && @volume_disk_ext_id !~ pattern
    invalid_properties.push("invalid value for \"volume_disk_ext_id\", must conform to the pattern #{pattern}.")
  end

  if !@controller_user_bytes.nil? && @controller_user_bytes.length > 100
    invalid_properties.push('invalid value for "controller_user_bytes", number of items must be less than or equal to 100.')
  end

  if !@controller_user_bytes.nil? && @controller_user_bytes.length < 0
    invalid_properties.push('invalid value for "controller_user_bytes", number of items must be greater than or equal to 0.')
  end

  if !@controller_num_iops.nil? && @controller_num_iops.length > 100
    invalid_properties.push('invalid value for "controller_num_iops", number of items must be less than or equal to 100.')
  end

  if !@controller_num_iops.nil? && @controller_num_iops.length < 0
    invalid_properties.push('invalid value for "controller_num_iops", number of items must be greater than or equal to 0.')
  end

  if !@controller_num_read_iops.nil? && @controller_num_read_iops.length > 100
    invalid_properties.push('invalid value for "controller_num_read_iops", number of items must be less than or equal to 100.')
  end

  if !@controller_num_read_iops.nil? && @controller_num_read_iops.length < 0
    invalid_properties.push('invalid value for "controller_num_read_iops", number of items must be greater than or equal to 0.')
  end

  if !@controller_num_write_iops.nil? && @controller_num_write_iops.length > 100
    invalid_properties.push('invalid value for "controller_num_write_iops", number of items must be less than or equal to 100.')
  end

  if !@controller_num_write_iops.nil? && @controller_num_write_iops.length < 0
    invalid_properties.push('invalid value for "controller_num_write_iops", number of items must be greater than or equal to 0.')
  end

  if !@controller_io_bandwidth_k_bps.nil? && @controller_io_bandwidth_k_bps.length > 100
    invalid_properties.push('invalid value for "controller_io_bandwidth_k_bps", number of items must be less than or equal to 100.')
  end

  if !@controller_io_bandwidth_k_bps.nil? && @controller_io_bandwidth_k_bps.length < 0
    invalid_properties.push('invalid value for "controller_io_bandwidth_k_bps", number of items must be greater than or equal to 0.')
  end

  if !@controller_read_io_bandwidth_k_bps.nil? && @controller_read_io_bandwidth_k_bps.length > 100
    invalid_properties.push('invalid value for "controller_read_io_bandwidth_k_bps", number of items must be less than or equal to 100.')
  end

  if !@controller_read_io_bandwidth_k_bps.nil? && @controller_read_io_bandwidth_k_bps.length < 0
    invalid_properties.push('invalid value for "controller_read_io_bandwidth_k_bps", number of items must be greater than or equal to 0.')
  end

  if !@controller_write_io_bandwidth_k_bps.nil? && @controller_write_io_bandwidth_k_bps.length > 100
    invalid_properties.push('invalid value for "controller_write_io_bandwidth_k_bps", number of items must be less than or equal to 100.')
  end

  if !@controller_write_io_bandwidth_k_bps.nil? && @controller_write_io_bandwidth_k_bps.length < 0
    invalid_properties.push('invalid value for "controller_write_io_bandwidth_k_bps", number of items must be greater than or equal to 0.')
  end

  if !@controller_avg_io_latency_usecs.nil? && @controller_avg_io_latency_usecs.length > 100
    invalid_properties.push('invalid value for "controller_avg_io_latency_usecs", number of items must be less than or equal to 100.')
  end

  if !@controller_avg_io_latency_usecs.nil? && @controller_avg_io_latency_usecs.length < 0
    invalid_properties.push('invalid value for "controller_avg_io_latency_usecs", number of items must be greater than or equal to 0.')
  end

  if !@controller_avg_read_io_latency_usecs.nil? && @controller_avg_read_io_latency_usecs.length > 100
    invalid_properties.push('invalid value for "controller_avg_read_io_latency_usecs", number of items must be less than or equal to 100.')
  end

  if !@controller_avg_read_io_latency_usecs.nil? && @controller_avg_read_io_latency_usecs.length < 0
    invalid_properties.push('invalid value for "controller_avg_read_io_latency_usecs", number of items must be greater than or equal to 0.')
  end

  if !@controller_avg_write_io_latency_usecs.nil? && @controller_avg_write_io_latency_usecs.length > 100
    invalid_properties.push('invalid value for "controller_avg_write_io_latency_usecs", number of items must be less than or equal to 100.')
  end

  if !@controller_avg_write_io_latency_usecs.nil? && @controller_avg_write_io_latency_usecs.length < 0
    invalid_properties.push('invalid value for "controller_avg_write_io_latency_usecs", number of items must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



660
661
662
663
664
665
666
667
668
669
670
671
672
# File 'lib/nutanix_volumes/models/volumes_v40_stats_volume_disk_stats.rb', line 660

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/nutanix_volumes/models/volumes_v40_stats_volume_disk_stats.rb', line 333

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@tenant_id.nil? && @tenant_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  return false if !@ext_id.nil? && @ext_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  return false if !@links.nil? && @links.length > 20
  return false if !@links.nil? && @links.length < 0
  return false if !@volume_disk_ext_id.nil? && @volume_disk_ext_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/)
  return false if !@controller_user_bytes.nil? && @controller_user_bytes.length > 100
  return false if !@controller_user_bytes.nil? && @controller_user_bytes.length < 0
  return false if !@controller_num_iops.nil? && @controller_num_iops.length > 100
  return false if !@controller_num_iops.nil? && @controller_num_iops.length < 0
  return false if !@controller_num_read_iops.nil? && @controller_num_read_iops.length > 100
  return false if !@controller_num_read_iops.nil? && @controller_num_read_iops.length < 0
  return false if !@controller_num_write_iops.nil? && @controller_num_write_iops.length > 100
  return false if !@controller_num_write_iops.nil? && @controller_num_write_iops.length < 0
  return false if !@controller_io_bandwidth_k_bps.nil? && @controller_io_bandwidth_k_bps.length > 100
  return false if !@controller_io_bandwidth_k_bps.nil? && @controller_io_bandwidth_k_bps.length < 0
  return false if !@controller_read_io_bandwidth_k_bps.nil? && @controller_read_io_bandwidth_k_bps.length > 100
  return false if !@controller_read_io_bandwidth_k_bps.nil? && @controller_read_io_bandwidth_k_bps.length < 0
  return false if !@controller_write_io_bandwidth_k_bps.nil? && @controller_write_io_bandwidth_k_bps.length > 100
  return false if !@controller_write_io_bandwidth_k_bps.nil? && @controller_write_io_bandwidth_k_bps.length < 0
  return false if !@controller_avg_io_latency_usecs.nil? && @controller_avg_io_latency_usecs.length > 100
  return false if !@controller_avg_io_latency_usecs.nil? && @controller_avg_io_latency_usecs.length < 0
  return false if !@controller_avg_read_io_latency_usecs.nil? && @controller_avg_read_io_latency_usecs.length > 100
  return false if !@controller_avg_read_io_latency_usecs.nil? && @controller_avg_read_io_latency_usecs.length < 0
  return false if !@controller_avg_write_io_latency_usecs.nil? && @controller_avg_write_io_latency_usecs.length > 100
  return false if !@controller_avg_write_io_latency_usecs.nil? && @controller_avg_write_io_latency_usecs.length < 0
  true
end