Class: NutanixVolumes::VolumesV40ConfigIscsiClient
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixVolumes::VolumesV40ConfigIscsiClient
- Defined in:
- lib/nutanix_volumes/models/volumes_v40_config_iscsi_client.rb
Overview
A model that represents an iSCSI client that can be associated with a Volume Group as an external attachment.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#attached_targets ⇒ Object
Returns the value of attribute attached_targets.
-
#attachment_site ⇒ Object
Returns the value of attribute attachment_site.
-
#client_secret ⇒ Object
iSCSI initiator client secret in case of CHAP authentication.
-
#cluster_reference ⇒ Object
The UUID of the cluster that will host the iSCSI client.
-
#enabled_authentications ⇒ Object
Returns the value of attribute enabled_authentications.
-
#ext_id ⇒ Object
A globally unique identifier of an instance that is suitable for external consumption.
-
#iscsi_initiator_name ⇒ Object
iSCSI initiator name.
-
#iscsi_initiator_network_id ⇒ Object
Returns the value of attribute iscsi_initiator_network_id.
-
#links ⇒ Object
A HATEOAS style link for the response.
-
#num_virtual_targets ⇒ Object
Number of virtual targets generated for the iSCSI target.
-
#tenant_id ⇒ Object
A globally unique identifier that represents the tenant that owns this entity.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VolumesV40ConfigIscsiClient
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VolumesV40ConfigIscsiClient
Initializes the object
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_client.rb', line 130 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVolumes::VolumesV40ConfigIscsiClient` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVolumes::VolumesV40ConfigIscsiClient`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'tenant_id') self.tenant_id = attributes[:'tenant_id'] end if attributes.key?(:'ext_id') self.ext_id = attributes[:'ext_id'] end if attributes.key?(:'links') if (value = attributes[:'links']).is_a?(Array) self.links = value end end if attributes.key?(:'iscsi_initiator_name') self.iscsi_initiator_name = attributes[:'iscsi_initiator_name'] end if attributes.key?(:'iscsi_initiator_network_id') self.iscsi_initiator_network_id = attributes[:'iscsi_initiator_network_id'] end if attributes.key?(:'client_secret') self.client_secret = attributes[:'client_secret'] end if attributes.key?(:'enabled_authentications') self.enabled_authentications = attributes[:'enabled_authentications'] end if attributes.key?(:'attached_targets') if (value = attributes[:'attached_targets']).is_a?(Array) self.attached_targets = value end end if attributes.key?(:'num_virtual_targets') self.num_virtual_targets = attributes[:'num_virtual_targets'] end if attributes.key?(:'cluster_reference') self.cluster_reference = attributes[:'cluster_reference'] end if attributes.key?(:'attachment_site') self. = attributes[:'attachment_site'] end end |
Instance Attribute Details
#attached_targets ⇒ Object
Returns the value of attribute attached_targets.
38 39 40 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_client.rb', line 38 def attached_targets @attached_targets end |
#attachment_site ⇒ Object
Returns the value of attribute attachment_site.
46 47 48 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_client.rb', line 46 def @attachment_site end |
#client_secret ⇒ Object
iSCSI initiator client secret in case of CHAP authentication. This field should not be provided if the authentication type is not set to CHAP.
34 35 36 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_client.rb', line 34 def client_secret @client_secret end |
#cluster_reference ⇒ Object
The UUID of the cluster that will host the iSCSI client. This field is read-only.
44 45 46 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_client.rb', line 44 def cluster_reference @cluster_reference end |
#enabled_authentications ⇒ Object
Returns the value of attribute enabled_authentications.
36 37 38 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_client.rb', line 36 def enabled_authentications @enabled_authentications end |
#ext_id ⇒ Object
A globally unique identifier of an instance that is suitable for external consumption.
23 24 25 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_client.rb', line 23 def ext_id @ext_id end |
#iscsi_initiator_name ⇒ Object
iSCSI initiator name. Exactly one of iscsiInitiatorName and iscsiInitiatorNetworkId must be specified during the attach operation. This field is immutable.
29 30 31 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_client.rb', line 29 def iscsi_initiator_name @iscsi_initiator_name end |
#iscsi_initiator_network_id ⇒ Object
Returns the value of attribute iscsi_initiator_network_id.
31 32 33 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_client.rb', line 31 def iscsi_initiator_network_id @iscsi_initiator_network_id end |
#links ⇒ Object
A HATEOAS style link for the response. Each link contains a user-friendly name identifying the link and an address for retrieving the particular resource.
26 27 28 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_client.rb', line 26 def links @links end |
#num_virtual_targets ⇒ Object
Number of virtual targets generated for the iSCSI target. This field is immutable.
41 42 43 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_client.rb', line 41 def num_virtual_targets @num_virtual_targets end |
#tenant_id ⇒ Object
A globally unique identifier that represents the tenant that owns this entity. The system automatically assigns it, and it and is immutable from an API consumer perspective (some use cases may cause this Id to change - For instance, a use case may require the transfer of ownership of the entity, but these cases are handled automatically on the server).
20 21 22 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_client.rb', line 20 def tenant_id @tenant_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
88 89 90 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_client.rb', line 88 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
93 94 95 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_client.rb', line 93 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_client.rb', line 71 def self.attribute_map { :'tenant_id' => :'tenantId', :'ext_id' => :'extId', :'links' => :'links', :'iscsi_initiator_name' => :'iscsiInitiatorName', :'iscsi_initiator_network_id' => :'iscsiInitiatorNetworkId', :'client_secret' => :'clientSecret', :'enabled_authentications' => :'enabledAuthentications', :'attached_targets' => :'attachedTargets', :'num_virtual_targets' => :'numVirtualTargets', :'cluster_reference' => :'clusterReference', :'attachment_site' => :'attachmentSite' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_client.rb', line 403 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
122 123 124 125 126 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_client.rb', line 122 def self.openapi_all_of [ :'CommonV10ResponseExternalizableAbstractModel' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
115 116 117 118 119 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_client.rb', line 115 def self.openapi_nullable Set.new([ :'ext_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_client.rb', line 98 def self.openapi_types { :'tenant_id' => :'String', :'ext_id' => :'String', :'links' => :'Array<CommonV10ResponseApiLink>', :'iscsi_initiator_name' => :'String', :'iscsi_initiator_network_id' => :'CommonV10ConfigIPAddressOrFQDN', :'client_secret' => :'String', :'enabled_authentications' => :'VolumesV40ConfigAuthenticationType', :'attached_targets' => :'Array<VolumesV40ConfigTargetParam>', :'num_virtual_targets' => :'Integer', :'cluster_reference' => :'String', :'attachment_site' => :'VolumesV40ConfigVolumeGroupAttachmentSite' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_client.rb', line 372 def ==(o) return true if self.equal?(o) self.class == o.class && tenant_id == o.tenant_id && ext_id == o.ext_id && links == o.links && iscsi_initiator_name == o.iscsi_initiator_name && iscsi_initiator_network_id == o.iscsi_initiator_network_id && client_secret == o.client_secret && enabled_authentications == o.enabled_authentications && attached_targets == o.attached_targets && num_virtual_targets == o.num_virtual_targets && cluster_reference == o.cluster_reference && == o. end |
#eql?(o) ⇒ Boolean
390 391 392 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_client.rb', line 390 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
396 397 398 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_client.rb', line 396 def hash [tenant_id, ext_id, links, iscsi_initiator_name, iscsi_initiator_network_id, client_secret, enabled_authentications, attached_targets, num_virtual_targets, cluster_reference, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_client.rb', line 195 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@tenant_id.nil? && @tenant_id !~ pattern invalid_properties.push("invalid value for \"tenant_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@ext_id.nil? && @ext_id !~ pattern invalid_properties.push("invalid value for \"ext_id\", must conform to the pattern #{pattern}.") end if !@links.nil? && @links.length > 20 invalid_properties.push('invalid value for "links", number of items must be less than or equal to 20.') end if !@links.nil? && @links.length < 0 invalid_properties.push('invalid value for "links", number of items must be greater than or equal to 0.') end if !@iscsi_initiator_name.nil? && @iscsi_initiator_name.to_s.length > 64 invalid_properties.push('invalid value for "iscsi_initiator_name", the character length must be smaller than or equal to 64.') end if !@client_secret.nil? && @client_secret.to_s.length > 16 invalid_properties.push('invalid value for "client_secret", the character length must be smaller than or equal to 16.') end if !@client_secret.nil? && @client_secret.to_s.length < 12 invalid_properties.push('invalid value for "client_secret", the character length must be greater than or equal to 12.') end if !@attached_targets.nil? && @attached_targets.length > 128 invalid_properties.push('invalid value for "attached_targets", number of items must be less than or equal to 128.') end if !@attached_targets.nil? && @attached_targets.length < 0 invalid_properties.push('invalid value for "attached_targets", number of items must be greater than or equal to 0.') end pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@cluster_reference.nil? && @cluster_reference !~ pattern invalid_properties.push("invalid value for \"cluster_reference\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
425 426 427 428 429 430 431 432 433 434 435 436 437 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_client.rb', line 425 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_iscsi_client.rb', line 246 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@tenant_id.nil? && @tenant_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) return false if !@ext_id.nil? && @ext_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) return false if !@links.nil? && @links.length > 20 return false if !@links.nil? && @links.length < 0 return false if !@iscsi_initiator_name.nil? && @iscsi_initiator_name.to_s.length > 64 return false if !@client_secret.nil? && @client_secret.to_s.length > 16 return false if !@client_secret.nil? && @client_secret.to_s.length < 12 return false if !@attached_targets.nil? && @attached_targets.length > 128 return false if !@attached_targets.nil? && @attached_targets.length < 0 return false if !@cluster_reference.nil? && @cluster_reference !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) true end |