Class: NutanixVolumes::VolumesV40ConfigVolumeDisk
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- NutanixVolumes::VolumesV40ConfigVolumeDisk
- Defined in:
- lib/nutanix_volumes/models/volumes_v40_config_volume_disk.rb
Overview
A model that represents a Volume Disk associated with a Volume Group, supported by a backing file on DSF.
Instance Attribute Summary collapse
-
#description ⇒ Object
Volume Disk description.
-
#disk_data_source_reference ⇒ Object
Returns the value of attribute disk_data_source_reference.
-
#disk_size_bytes ⇒ Object
Size of the disk in bytes.
-
#disk_storage_features ⇒ Object
Returns the value of attribute disk_storage_features.
-
#ext_id ⇒ Object
A globally unique identifier of an instance that is suitable for external consumption.
-
#index ⇒ Object
Index of the disk in a Volume Group.
-
#links ⇒ Object
A HATEOAS style link for the response.
-
#storage_container_id ⇒ Object
Storage container on which the disk must be created.
-
#tenant_id ⇒ Object
A globally unique identifier that represents the tenant that owns this entity.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VolumesV40ConfigVolumeDisk
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VolumesV40ConfigVolumeDisk
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_volume_disk.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `NutanixVolumes::VolumesV40ConfigVolumeDisk` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `NutanixVolumes::VolumesV40ConfigVolumeDisk`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'tenant_id') self.tenant_id = attributes[:'tenant_id'] end if attributes.key?(:'ext_id') self.ext_id = attributes[:'ext_id'] end if attributes.key?(:'links') if (value = attributes[:'links']).is_a?(Array) self.links = value end end if attributes.key?(:'index') self.index = attributes[:'index'] end if attributes.key?(:'disk_size_bytes') self.disk_size_bytes = attributes[:'disk_size_bytes'] end if attributes.key?(:'storage_container_id') self.storage_container_id = attributes[:'storage_container_id'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'disk_data_source_reference') self.disk_data_source_reference = attributes[:'disk_data_source_reference'] end if attributes.key?(:'disk_storage_features') self.disk_storage_features = attributes[:'disk_storage_features'] end end |
Instance Attribute Details
#description ⇒ Object
Volume Disk description. This is an optional field.
38 39 40 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_volume_disk.rb', line 38 def description @description end |
#disk_data_source_reference ⇒ Object
Returns the value of attribute disk_data_source_reference.
40 41 42 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_volume_disk.rb', line 40 def disk_data_source_reference @disk_data_source_reference end |
#disk_size_bytes ⇒ Object
Size of the disk in bytes. This field is mandatory during Volume Group creation if a new disk is created on the storage container.
32 33 34 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_volume_disk.rb', line 32 def disk_size_bytes @disk_size_bytes end |
#disk_storage_features ⇒ Object
Returns the value of attribute disk_storage_features.
42 43 44 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_volume_disk.rb', line 42 def disk_storage_features @disk_storage_features end |
#ext_id ⇒ Object
A globally unique identifier of an instance that is suitable for external consumption.
23 24 25 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_volume_disk.rb', line 23 def ext_id @ext_id end |
#index ⇒ Object
Index of the disk in a Volume Group. This field is optional and immutable.
29 30 31 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_volume_disk.rb', line 29 def index @index end |
#links ⇒ Object
A HATEOAS style link for the response. Each link contains a user-friendly name identifying the link and an address for retrieving the particular resource.
26 27 28 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_volume_disk.rb', line 26 def links @links end |
#storage_container_id ⇒ Object
Storage container on which the disk must be created. This is a read-only field.
35 36 37 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_volume_disk.rb', line 35 def storage_container_id @storage_container_id end |
#tenant_id ⇒ Object
A globally unique identifier that represents the tenant that owns this entity. The system automatically assigns it, and it and is immutable from an API consumer perspective (some use cases may cause this Id to change - For instance, a use case may require the transfer of ownership of the entity, but these cases are handled automatically on the server).
20 21 22 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_volume_disk.rb', line 20 def tenant_id @tenant_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
60 61 62 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_volume_disk.rb', line 60 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
65 66 67 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_volume_disk.rb', line 65 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_volume_disk.rb', line 45 def self.attribute_map { :'tenant_id' => :'tenantId', :'ext_id' => :'extId', :'links' => :'links', :'index' => :'index', :'disk_size_bytes' => :'diskSizeBytes', :'storage_container_id' => :'storageContainerId', :'description' => :'description', :'disk_data_source_reference' => :'diskDataSourceReference', :'disk_storage_features' => :'diskStorageFeatures' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_volume_disk.rb', line 361 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
92 93 94 95 96 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_volume_disk.rb', line 92 def self.openapi_all_of [ :'CommonV10ResponseExternalizableAbstractModel' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
85 86 87 88 89 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_volume_disk.rb', line 85 def self.openapi_nullable Set.new([ :'ext_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_volume_disk.rb', line 70 def self.openapi_types { :'tenant_id' => :'String', :'ext_id' => :'String', :'links' => :'Array<CommonV10ResponseApiLink>', :'index' => :'Integer', :'disk_size_bytes' => :'Integer', :'storage_container_id' => :'String', :'description' => :'String', :'disk_data_source_reference' => :'CommonV10ConfigEntityReference', :'disk_storage_features' => :'VolumesV40ConfigDiskStorageFeatures' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
332 333 334 335 336 337 338 339 340 341 342 343 344 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_volume_disk.rb', line 332 def ==(o) return true if self.equal?(o) self.class == o.class && tenant_id == o.tenant_id && ext_id == o.ext_id && links == o.links && index == o.index && disk_size_bytes == o.disk_size_bytes && storage_container_id == o.storage_container_id && description == o.description && disk_data_source_reference == o.disk_data_source_reference && disk_storage_features == o.disk_storage_features end |
#eql?(o) ⇒ Boolean
348 349 350 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_volume_disk.rb', line 348 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
354 355 356 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_volume_disk.rb', line 354 def hash [tenant_id, ext_id, links, index, disk_size_bytes, storage_container_id, description, disk_data_source_reference, disk_storage_features].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_volume_disk.rb', line 155 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@tenant_id.nil? && @tenant_id !~ pattern invalid_properties.push("invalid value for \"tenant_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@ext_id.nil? && @ext_id !~ pattern invalid_properties.push("invalid value for \"ext_id\", must conform to the pattern #{pattern}.") end if !@links.nil? && @links.length > 20 invalid_properties.push('invalid value for "links", number of items must be less than or equal to 20.') end if !@links.nil? && @links.length < 0 invalid_properties.push('invalid value for "links", number of items must be greater than or equal to 0.') end if !@index.nil? && @index > 16383 invalid_properties.push('invalid value for "index", must be smaller than or equal to 16383.') end if !@index.nil? && @index < 0 invalid_properties.push('invalid value for "index", must be greater than or equal to 0.') end if !@disk_size_bytes.nil? && @disk_size_bytes > 219902325555200 invalid_properties.push('invalid value for "disk_size_bytes", must be smaller than or equal to 219902325555200.') end if !@disk_size_bytes.nil? && @disk_size_bytes < 524288 invalid_properties.push('invalid value for "disk_size_bytes", must be greater than or equal to 524288.') end pattern = Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) if !@storage_container_id.nil? && @storage_container_id !~ pattern invalid_properties.push("invalid value for \"storage_container_id\", must conform to the pattern #{pattern}.") end if !@description.nil? && @description.to_s.length > 1000 invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 1000.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_volume_disk.rb', line 383 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/nutanix_volumes/models/volumes_v40_config_volume_disk.rb', line 206 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@tenant_id.nil? && @tenant_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) return false if !@ext_id.nil? && @ext_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) return false if !@links.nil? && @links.length > 20 return false if !@links.nil? && @links.length < 0 return false if !@index.nil? && @index > 16383 return false if !@index.nil? && @index < 0 return false if !@disk_size_bytes.nil? && @disk_size_bytes > 219902325555200 return false if !@disk_size_bytes.nil? && @disk_size_bytes < 524288 return false if !@storage_container_id.nil? && @storage_container_id !~ Regexp.new(/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}$/) return false if !@description.nil? && @description.to_s.length > 1000 true end |